# Generated by Django 2.0 on 2018-08-24 14:46

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0072_remove_callbackentry_member'),
    ]

    operations = [
        migrations.AddField(
            model_name='boardstatus',
            name='escalation_status',
            field=models.CharField(blank=True, choices=[('NotResponded', 'Not Responded'), ('Responded', 'Responded'), ('ResolutionPlan', 'Resolution Plan'), ('Resolved', 'Resolved'), ('NoEscalation', 'No Escalation')], db_index=True, max_length=20, null=True),
        ),
        migrations.AddField(
            model_name='company',
            name='calendar',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djconnectwise.Calendar'),
        ),
        migrations.AddField(
            model_name='ticket',
            name='do_not_escalate_date',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='minutes_waiting',
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name='ticket',
            name='sla_expire_date',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='sla_stage',
            field=models.CharField(blank=True, choices=[('respond', 'Respond'), ('plan', 'Plan'), ('resolve', 'Resolve'), ('resolved', 'Resolved'), ('waiting', 'Waiting')], db_index=True, max_length=250, null=True),
        ),
    ]
